@@ -137,7 +137,7 @@ class netlist_utilsTest(unittest.TestCase):
     def test_write_netlist(self):
         net = lp.setup_circuit(Np=1, Ns=2, Rb=1e-4, Rc=1e-2, Ri=1e-3, V=2.0, I=10.0)
         cwd = os.getcwd()
-        temp = os.path.join(cwd, 'temp.txt')
+        temp = os.path.join(cwd, "temp.txt")
         lp.write_netlist(net, temp)
         assert os.path.isfile(temp)
         os.remove(temp)
